@@ -184,8 +184,12 @@ class Instrument:
         :param general: parse general data including bvol, cisin, etc.
         :param trade_history: include trade_history in the result.
         :param related_companies: parse and include related_companies.
-        For the meaning of keys see:
-            https://cdn.tsetmc.com/Site.aspx?ParTree=151713
+
+        For the meaning of yval column values see:
+            https://members.tsetmc.com/Site.aspx?ParTree=1114111118&LnkIdn=83
+
+        For the meaning of other column names see:
+            http://www.tsetmc.com/Site.aspx?ParTree=151713
         """
         text = await _get_par_tree(f'151311&i={self.code}')
         if general:
@@ -585,6 +589,9 @@ class Instrument:
         """Return an object resembling Instrument on a specific date.
 
         :param date: Gregorian date in YYYYMMDD format.
+
+        :note: methods of InstrumentOnDate are rate-limited.
+            Avoid making simultaneous calls.
         """
         return InstrumentOnDate(_inst=self, _date=date)
 
@@ -601,6 +608,9 @@ class InstrumentOnDate:
 
         Users should not instantiate this class directly, but use
         :meth:`Instrument.on_date` instead.
+
+        :note: methods of InstrumentOnDate are rate-limited.
+            Avoid making simultaneous calls.
         """
         self.date = _date
         self.inst = _inst
